@@ -294,7 +294,7 @@ def make_dispatcher(name, redis : Redis, max_ttl = 60, max_size = 100, on_except
 
                 # the two calls below is not strictly safe, cuz there is a situation
                 # that remote callback executed earlier than the second call
-                await remote_call(task)
+                await remote_call(task, *args, **kwargs)
                 await wait_for_resolve(task)
 
                 return task
